# Yuio

This is a lightweight, no-dependency python module for building simple human-friendly CLIs
with python. 

Yuio's features are:

- small, no-dependencies;
- colored output;
- status indication with progress bars;
- user interactions and input parsing;
- building configs and loading them from file system, env vars or command line arguments;
- and more.

It is ideal for small things such as automation scripts, utilities for CI, or any other tools.
Without dependencies, it is easy to use it in places where you either don't or don't want to have
access to dependency management systems. Just copy-paste its source files into your project,
and be done with it.

---

![A light-purple-haired catgirl smiling at you and showing heart with her hands](https://github.com/taminomara/yuio/raw/main/docs/source/_static/yuio_small.png "Picture of Yuio")

---

- [Documentation](https://yuio.readthedocs.io/en/stable/)
- [Issues](https://github.com/taminomara/yuio/issues)
- [Source](https://github.com/taminomara/yuio/)
- [PyPi](https://pypi.org/project/yuio/)

## Requirements

- python >= 3.8

## Installation

```sh
pip3 install yuio
```

Or just copy-paste the `yuio` directory to somewhere in the `PYTHONPATH` of your project.

## Changelog

*v1.0.0*:

- Initial release.
